Orange3 Story Navigator Add-on
==============================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/dsgdepparser
   widgets/dsgruleset
   widgets/dsgsrl
   widgets/dsgtagger
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
